@@ -3,7 +3,21 @@ import os
 
 CLI_CONFIG = {
     "ver": {"positional": True},
-    "skip": {"nargs": "*"},
+    "skip": {
+        "nargs": "*",
+        "choices": [
+            "coerce",
+            "version",
+            "test",
+            "commit",
+            "tag",
+            "clean",
+            "build",
+            "input",
+            "release",
+            "push",
+        ],
+    },
     "remote": {},
     "root": {},
     "acct_file": {"source": "acct"},
@@ -15,7 +29,10 @@ CONFIG = {
         "help": "The semantic version number to apply to the release",
         "default": None,
     },
-    "skip": {"help": "Skip phases with the given names", "default": None},
+    "skip": {
+        "help": "Skip phases with the given names in the release process",
+        "default": None,
+    },
     "remote": {
         "help": "The git remote to use when pushing a release",
         "default": "origin",
